@@ -1,14 +1,16 @@
 ENDING_MINUTIAE = "ending"
 BIFURCATION_MINUTIAE = "bifurcation"
 FRAGMENT_MINUTIAE = "fragment"
+ENCLOSURE_MINUTIAE = "enclosure"
+CROSSBAR_MINUTIAE = "crossbar"
 OTHER_MINUTIAE = "other"
 
 MINUTIAE_CLASSES = [ENDING_MINUTIAE, BIFURCATION_MINUTIAE,
-                    FRAGMENT_MINUTIAE, OTHER_MINUTIAE]
+                    FRAGMENT_MINUTIAE, ENCLOSURE_MINUTIAE, CROSSBAR_MINUTIAE, OTHER_MINUTIAE]
 
 PATCH_MINU_RADIO = 22
 
-NUM_CLASSES = 4
+NUM_CLASSES = 6
 
 INPUT_SHAPE = (224, 224, 3)
 
@@ -18,3 +20,6 @@ BLUE_COLOR = 'b'
 GREEN_COLOR = 'g'
 CYAN_COLOR = 'c'
 MAGENTA_COLOR = 'm'
+YELLOW_COLOR = 'y'
+BLACK_COLOR = 'k'
+WHITE_COLOR = 'w'
